==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/TemplateBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class TemplateBuilder extends io.fabric8.openshift.api.model.TemplateFluentImpl<io.fabric8.openshift.api.model.TemplateBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.Template,io.fabric8.openshift.api.model.TemplateBuilder>{
  public TemplateBuilder() {
    this(false);
  }
  public TemplateBuilder(java.lang.Boolean validationEnabled) {
    this(new Template(), validationEnabled);
  }
  public TemplateBuilder(io.fabric8.openshift.api.model.TemplateFluent<?> fluent) {
    this(fluent, false);
  }
  public TemplateBuilder(io.fabric8.openshift.api.model.TemplateFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Template(), validationEnabled);
  }
  public TemplateBuilder(io.fabric8.openshift.api.model.TemplateFluent<?> fluent,io.fabric8.openshift.api.model.Template instance) {
    this(fluent, instance, false);
  }
  public TemplateBuilder(io.fabric8.openshift.api.model.TemplateFluent<?> fluent,io.fabric8.openshift.api.model.Template instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withLabels(instance.getLabels()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withObjects(instance.getObjects()); 
    fluent.withParameters(instance.getParameters()); 
    this.validationEnabled = validationEnabled; 
  }
  public TemplateBuilder(io.fabric8.openshift.api.model.Template instance) {
    this(instance,false);
  }
  public TemplateBuilder(io.fabric8.openshift.api.model.Template instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withLabels(instance.getLabels()); 
    this.withMetadata(instance.getMetadata()); 
    this.withObjects(instance.getObjects()); 
    this.withParameters(instance.getParameters()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.TemplateFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.Template build() {
    Template buildable = new Template(fluent.getApiVersion(),fluent.getKind(),fluent.getLabels(),fluent.getMetadata(),fluent.getObjects(),fluent.getParameters());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TemplateBuilder that = (TemplateBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/TemplateBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class TemplateBuilder extends io.fabric8.openshift.api.model.TemplateFluentImpl<io.fabric8.openshift.api.model.TemplateBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.Template,io.fabric8.openshift.api.model.TemplateBuilder>{
  public TemplateBuilder() {
    this(false);
  }
  public TemplateBuilder(java.lang.Boolean validationEnabled) {
    this(new Template(), validationEnabled);
  }
  public TemplateBuilder(io.fabric8.openshift.api.model.TemplateFluent<?> fluent) {
    this(fluent, false);
  }
  public TemplateBuilder(io.fabric8.openshift.api.model.TemplateFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Template(), validationEnabled);
  }
  public TemplateBuilder(io.fabric8.openshift.api.model.TemplateFluent<?> fluent,io.fabric8.openshift.api.model.Template instance) {
    this(fluent, instance, false);
  }
  public TemplateBuilder(io.fabric8.openshift.api.model.TemplateFluent<?> fluent,io.fabric8.openshift.api.model.Template instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withLabels(instance.getLabels()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withObjects(instance.getObjects()); 
    fluent.withParameters(instance.getParameters()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public TemplateBuilder(io.fabric8.openshift.api.model.Template instance) {
    this(instance,false);
  }
  public TemplateBuilder(io.fabric8.openshift.api.model.Template instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withLabels(instance.getLabels()); 
    this.withMetadata(instance.getMetadata()); 
    this.withObjects(instance.getObjects()); 
    this.withParameters(instance.getParameters()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.TemplateFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.Template build() {
    Template buildable = new Template(fluent.getApiVersion(),fluent.getKind(),fluent.getLabels(),fluent.getMetadata(),fluent.getObjects(),fluent.getParameters());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TemplateBuilder that = (TemplateBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
